%global openblas_arches x86_64 %{power64} aarch64
%undefine __cmake_in_source_build

Summary:        Fast C++ matrix library with syntax similar to MATLAB and Octave
Name:           armadillo
Version:        10.8.2
Release:        2%{?dist}

License:        ASL 2.0
URL:            http://arma.sourceforge.net/
Source0:         http://sourceforge.net/projects/arma/files/%{name}-%{version}.tar.xz

BuildRequires: hdf5-devel SuperLU-devel flexiblas-devel atlas-devel
BuildRequires: gcc-c++ cmake make arpack-devel
BuildRequires: atlas-devel lapack-devel
%ifarch %{openblas_arches}
BuildRequires:  openblas-devel
%endif

%description
Armadillo is a high quality linear algebra library (matrix maths) for the C++ language, aiming towards a good balance between speed and ease of use
Provides high-level syntax and functionality deliberately similar to Matlab
Useful for algorithm development directly in C++, or quick conversion of research code into production environments
Provides efficient classes for vectors, matrices and cubes; dense and sparse matrices are supported
Integer, floating point and complex numbers are supported
A sophisticated expression evaluator (based on template meta-programming) automatically combines several operations to increase speed and efficiency
Dynamic evaluation automatically chooses optimal code paths based on detected matrix structures
Various matrix decompositions (eigen, SVD, QR, etc) are provided through integration with LAPACK, or one of its high performance drop-in replacements (eg. MKL or OpenBLAS)
Can automatically use OpenMP multi-threading (parallelisation) to speed up computationally expensive operations
Distributed under the permissive Apache 2.0 license, useful for both open-source and proprietary (closed-source) software
Can be used for machine learning, pattern recognition, computer vision, signal processing, bioinformatics, statistics, finance, etc


%package devel
Summary:        Development headers and documentation for the Armadillo C++ library
Requires:       %{name} = %{version}-%{release}
Requires:       libstdc++-devel arpack-devel hdf5-devel SuperLU-devel atlas-devel lapack-devel
%ifarch %{openblas_arches}
Requires:  openblas-devel
%endif

%description devel
This package provides header files necessary for development using the
Armadillo C++ library.


%prep
%autosetup -p1
sed -i 's/\r//' README.md
rm -rf examples/*win64*


%build
%cmake
%cmake_build


%install
%cmake_install


%ifnarch aarch64
%check
%cmake -DBUILD_SMOKE_TEST=ON
make -C "%{_vpath_builddir}"
%ctest
%endif


%files
%license LICENSE.txt NOTICE.txt
%{_libdir}/libarmadillo.so.10*

%files devel
%doc README.md index.html docs.html examples
%doc armadillo_icon.png mex_interface armadillo_nicta_2010.pdf
%doc rcpp_armadillo_csda_2014.pdf armadillo_joss_2016.pdf
%doc armadillo_spcs_2017.pdf armadillo_lncs_2018.pdf
%doc armadillo_solver_2020.pdf
%{_libdir}/libarmadillo.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/armadillo
%{_includedir}/armadillo_bits/
%{_datadir}/Armadillo/


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.8.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 cunshunxia <cunshunxia@tencent.com> - 10.8.2-1
- initial build
